/**
 * 
 * convert properties file from selected encoding into correct UCS2 escaped properties or xml properties file.
 * Written by Tomi Panula-Ontto
 * 
 * Downloaded from http://tomi.panula-ont.to/i18n/
 * 
 */

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.util.Properties;
import java.nio.charset.Charset;

public class ToProperties {

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		String COMMENT = "Generated with ToProperties from http://tomi.panula-ont.to/i18n/";
		String encoding = "UTF-8";
		if( args.length<2 || args.length>3 ) {
			System.out.println("Usage: java utf8toproperties srcWrongEncoding.properties dest.ext [srcEncoding]");
			System.out.println("Rationale: often your text editor (like notepad.exe) does not support writing .properties files in correct format.");
			System.out.println("Rationale: this program converts .properties files from standard format to correct UCS2 escaped .properties file or XML propertiesformat");
			System.out.println("Destination file recognizes extensions .properties and .xml");
			System.out.println("Default encoding: UTF-8");
			System.out.println("Native encoding on this platform: " + Charset.defaultCharset().displayName());
			System.exit(-1);
			return;
		}
		if( args.length==3 ) {
			encoding = args[2];
		}
		if( !(!args[1].toLowerCase().endsWith(".properties")) ^ (!args[1].toLowerCase().endsWith(".xml"))) {
			System.err.println("File '"+args[1]+"': Only .properties or .xml supported!");
			System.exit(-1);
			return;
		}
		FileInputStream fis = null;
		try {
			fis = new FileInputStream(args[0]);	
		} catch( FileNotFoundException e1 ) {
			System.err.println("File '"+args[0]+"' not found!");
			System.exit(-1);
			return;
		}

		InputStreamReader isr = null;
		try {
			isr = new InputStreamReader(fis, encoding);
		} catch( UnsupportedEncodingException uee ) {
			System.err.println("Encoding '"+encoding+"' not supported!");
			System.exit(-1);
			return;
		}
		BufferedReader br = new BufferedReader(isr);
		Properties props = new Properties();
		try {
			String line = br.readLine();
			while( line!=null ) {
				int i = line.indexOf("=");
				String key = line.substring(0, i);
				String value = line.substring(i+1);
				props.setProperty(key, value);
				line = br.readLine();
			}
		} catch( IOException ioe ) {
			System.err.println("File '"+args[0]+"' read error!");
			System.exit(-1);
			return;
		}
		
		FileOutputStream fos;
		try {
			fos = new FileOutputStream(args[1]);
		} catch( FileNotFoundException e3 ) {
			System.err.println("File '"+args[1]+"' create error!");
			System.exit(-1);
			return;
		}
		if( args[1].toLowerCase().endsWith(".properties")) {
			try {
				props.store(fos, COMMENT);
			} catch( IOException ioe2 ) {
				System.err.println("File '"+args[1]+"' write error!");
				System.exit(-1);
			}
		} else {
			try {
				props.storeToXML(fos, COMMENT);
			} catch( IOException ioe2 ) {
				System.err.println("File '"+args[1]+"' write error!");
				System.exit(-1);
			}
		}
		try { fos.close(); } catch( IOException ignored ) {
			System.err.println("Warning: Error closing '"+args[1]+"'");
		}
		try { fis.close(); } catch( IOException ignored ) {
			System.err.println("Warning: Error closing '"+args[0]+"'");
		}
		System.exit(0);
	}

}
